/*
** Copyright 2020 Centreon
**
** Licensed under the Apache License, Version 2.0 (the "License");
** you may not use this file except in compliance with the License.
** You may obtain a copy of the License at
**
**     http://www.apache.org/licenses/LICENSE-2.0
**
** Unless required by applicable law or agreed to in writing, software
** distributed under the License is distributed on an "AS IS" BASIS,
** WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
** See the License for the specific language governing permissions and
** limitations under the License.
**
** For more information : contact@centreon.com
*/

#ifndef __TABLE_MAX_SIZE_HH__
#define __TABLE_MAX_SIZE_HH__

#include "com/centreon/broker/namespace.hh"

CCB_BEGIN()

enum acknowledgements_cols {
  acknowledgements_author,
  acknowledgements_comment_data,
};
constexpr static uint32_t acknowledgements_size[] {
    64,
    255,
};
constexpr uint32_t get_acknowledgements_col_size(
    acknowledgements_cols const& col) {
  return acknowledgements_size[col];
}

enum comments_cols {
  comments_author,
  comments_data,
};
constexpr static uint32_t comments_size[] {
    64,
    65534,
};
constexpr uint32_t get_comments_col_size(
    comments_cols const& col) {
  return comments_size[col];
}

enum customvariables_cols {
  customvariables_name,
  customvariables_default_value,
  customvariables_value,
};
constexpr static uint32_t customvariables_size[] {
    255,
    255,
    255,
};
constexpr uint32_t get_customvariables_col_size(
    customvariables_cols const& col) {
  return customvariables_size[col];
}

enum downtimes_cols {
  downtimes_author,
  downtimes_comment_data,
};
constexpr static uint32_t downtimes_size[] {
    64,
    65534,
};
constexpr uint32_t get_downtimes_col_size(
    downtimes_cols const& col) {
  return downtimes_size[col];
}

enum eventhandlers_cols {
  eventhandlers_command_args,
  eventhandlers_command_line,
  eventhandlers_output,
};
constexpr static uint32_t eventhandlers_size[] {
    255,
    255,
    255,
};
constexpr uint32_t get_eventhandlers_col_size(
    eventhandlers_cols const& col) {
  return eventhandlers_size[col];
}

enum hostgroups_cols {
  hostgroups_name,
};
constexpr static uint32_t hostgroups_size[] {
    255,
};
constexpr uint32_t get_hostgroups_col_size(
    hostgroups_cols const& col) {
  return hostgroups_size[col];
}

enum hosts_cols {
  hosts_name,
  hosts_action_url,
  hosts_address,
  hosts_alias,
  hosts_check_command,
  hosts_check_period,
  hosts_command_line,
  hosts_display_name,
  hosts_event_handler,
  hosts_icon_image,
  hosts_icon_image_alt,
  hosts_notes,
  hosts_notes_url,
  hosts_notification_period,
  hosts_output,
  hosts_perfdata,
  hosts_statusmap_image,
  hosts_timezone,
};
constexpr static uint32_t hosts_size[] {
    255,
    255,
    75,
    100,
    65534,
    75,
    65534,
    100,
    255,
    255,
    255,
    255,
    255,
    75,
    65534,
    65534,
    255,
    64,
};
constexpr uint32_t get_hosts_col_size(
    hosts_cols const& col) {
  return hosts_size[col];
}

enum hosts_hosts_dependencies_cols {
  hosts_hosts_dependencies_dependency_period,
  hosts_hosts_dependencies_execution_failure_options,
  hosts_hosts_dependencies_notification_failure_options,
};
constexpr static uint32_t hosts_hosts_dependencies_size[] {
    75,
    15,
    15,
};
constexpr uint32_t get_hosts_hosts_dependencies_col_size(
    hosts_hosts_dependencies_cols const& col) {
  return hosts_hosts_dependencies_size[col];
}

enum instances_cols {
  instances_name,
  instances_address,
  instances_description,
  instances_engine,
  instances_global_host_event_handler,
  instances_global_service_event_handler,
  instances_version,
};
constexpr static uint32_t instances_size[] {
    255,
    128,
    128,
    64,
    65534,
    65534,
    16,
};
constexpr uint32_t get_instances_col_size(
    instances_cols const& col) {
  return instances_size[col];
}

enum modules_cols {
  modules_args,
  modules_filename,
};
constexpr static uint32_t modules_size[] {
    255,
    255,
};
constexpr uint32_t get_modules_col_size(
    modules_cols const& col) {
  return modules_size[col];
}

enum notifications_cols {
  notifications_ack_author,
  notifications_ack_data,
  notifications_command_name,
  notifications_contact_name,
  notifications_output,
};
constexpr static uint32_t notifications_size[] {
    255,
    65534,
    255,
    255,
    65534,
};
constexpr uint32_t get_notifications_col_size(
    notifications_cols const& col) {
  return notifications_size[col];
}

enum schemaversion_cols {
  schemaversion_software,
};
constexpr static uint32_t schemaversion_size[] {
    128,
};
constexpr uint32_t get_schemaversion_col_size(
    schemaversion_cols const& col) {
  return schemaversion_size[col];
}

enum servicegroups_cols {
  servicegroups_name,
};
constexpr static uint32_t servicegroups_size[] {
    255,
};
constexpr uint32_t get_servicegroups_col_size(
    servicegroups_cols const& col) {
  return servicegroups_size[col];
}

enum services_cols {
  services_description,
  services_action_url,
  services_check_command,
  services_check_period,
  services_command_line,
  services_display_name,
  services_event_handler,
  services_failure_prediction_options,
  services_icon_image,
  services_icon_image_alt,
  services_notes,
  services_notes_url,
  services_notification_period,
  services_output,
  services_perfdata,
};
constexpr static uint32_t services_size[] {
    255,
    255,
    65534,
    75,
    65534,
    160,
    255,
    64,
    255,
    255,
    255,
    255,
    75,
    65534,
    65534,
};
constexpr uint32_t get_services_col_size(
    services_cols const& col) {
  return services_size[col];
}

enum services_services_dependencies_cols {
  services_services_dependencies_dependency_period,
  services_services_dependencies_execution_failure_options,
  services_services_dependencies_notification_failure_options,
};
constexpr static uint32_t services_services_dependencies_size[] {
    75,
    15,
    15,
};
constexpr uint32_t get_services_services_dependencies_col_size(
    services_services_dependencies_cols const& col) {
  return services_services_dependencies_size[col];
}

enum logs_cols {
  logs_host_name,
  logs_instance_name,
  logs_notification_cmd,
  logs_notification_contact,
  logs_output,
  logs_service_description,
};
constexpr static uint32_t logs_size[] {
    255,
    255,
    255,
    255,
    65534,
    255,
};
constexpr uint32_t get_logs_col_size(
    logs_cols const& col) {
  return logs_size[col];
}

enum mod_bam_cols {
  mod_bam_name,
  mod_bam_description,
  mod_bam_infrastructure_view,
  mod_bam_notification_options,
  mod_bam_geo_coords,
  mod_bam_event_handler_args,
  mod_bam_graph_style,
  mod_bam_comment,
};
constexpr static uint32_t mod_bam_size[] {
    254,
    254,
    254,
    255,
    32,
    254,
    254,
    65534,
};
constexpr uint32_t get_mod_bam_col_size(
    mod_bam_cols const& col) {
  return mod_bam_size[col];
}

enum mod_bam_kpi_cols {
  mod_bam_kpi_comment,
};
constexpr static uint32_t mod_bam_kpi_size[] {
    65534,
};
constexpr uint32_t get_mod_bam_kpi_col_size(
    mod_bam_kpi_cols const& col) {
  return mod_bam_kpi_size[col];
}

enum mod_bam_ba_groups_cols {
  mod_bam_ba_groups_ba_group_name,
  mod_bam_ba_groups_ba_group_description,
};
constexpr static uint32_t mod_bam_ba_groups_size[] {
    255,
    255,
};
constexpr uint32_t get_mod_bam_ba_groups_col_size(
    mod_bam_ba_groups_cols const& col) {
  return mod_bam_ba_groups_size[col];
}

enum mod_bam_user_preferences_cols {
  mod_bam_user_preferences_pref_key,
  mod_bam_user_preferences_pref_value,
};
constexpr static uint32_t mod_bam_user_preferences_size[] {
    255,
    255,
};
constexpr uint32_t get_mod_bam_user_preferences_col_size(
    mod_bam_user_preferences_cols const& col) {
  return mod_bam_user_preferences_size[col];
}

enum mod_bam_reporting_cols {
  mod_bam_reporting_host_name,
  mod_bam_reporting_service_description,
};
constexpr static uint32_t mod_bam_reporting_size[] {
    255,
    255,
};
constexpr uint32_t get_mod_bam_reporting_col_size(
    mod_bam_reporting_cols const& col) {
  return mod_bam_reporting_size[col];
}

enum mod_bam_reporting_status_cols {
  mod_bam_reporting_status_host_name,
  mod_bam_reporting_status_service_description,
  mod_bam_reporting_status_status,
};
constexpr static uint32_t mod_bam_reporting_status_size[] {
    255,
    255,
    255,
};
constexpr uint32_t get_mod_bam_reporting_status_col_size(
    mod_bam_reporting_status_cols const& col) {
  return mod_bam_reporting_status_size[col];
}

enum mod_bam_logs_cols {
  mod_bam_logs_status,
};
constexpr static uint32_t mod_bam_logs_size[] {
    255,
};
constexpr uint32_t get_mod_bam_logs_col_size(
    mod_bam_logs_cols const& col) {
  return mod_bam_logs_size[col];
}

enum mod_bam_kpi_logs_cols {
  mod_bam_kpi_logs_output,
  mod_bam_kpi_logs_kpi_name,
  mod_bam_kpi_logs_perfdata,
};
constexpr static uint32_t mod_bam_kpi_logs_size[] {
    255,
    255,
    65534,
};
constexpr uint32_t get_mod_bam_kpi_logs_col_size(
    mod_bam_kpi_logs_cols const& col) {
  return mod_bam_kpi_logs_size[col];
}

enum mod_bam_reporting_bv_cols {
  mod_bam_reporting_bv_bv_name,
  mod_bam_reporting_bv_bv_description,
};
constexpr static uint32_t mod_bam_reporting_bv_size[] {
    255,
    65534,
};
constexpr uint32_t get_mod_bam_reporting_bv_col_size(
    mod_bam_reporting_bv_cols const& col) {
  return mod_bam_reporting_bv_size[col];
}

enum mod_bam_reporting_ba_cols {
  mod_bam_reporting_ba_ba_name,
  mod_bam_reporting_ba_ba_description,
};
constexpr static uint32_t mod_bam_reporting_ba_size[] {
    254,
    65534,
};
constexpr uint32_t get_mod_bam_reporting_ba_col_size(
    mod_bam_reporting_ba_cols const& col) {
  return mod_bam_reporting_ba_size[col];
}

enum mod_bam_reporting_kpi_cols {
  mod_bam_reporting_kpi_kpi_name,
  mod_bam_reporting_kpi_ba_name,
  mod_bam_reporting_kpi_host_name,
  mod_bam_reporting_kpi_service_description,
  mod_bam_reporting_kpi_kpi_ba_name,
  mod_bam_reporting_kpi_meta_service_name,
  mod_bam_reporting_kpi_boolean_name,
};
constexpr static uint32_t mod_bam_reporting_kpi_size[] {
    255,
    254,
    255,
    255,
    254,
    254,
    255,
};
constexpr uint32_t get_mod_bam_reporting_kpi_col_size(
    mod_bam_reporting_kpi_cols const& col) {
  return mod_bam_reporting_kpi_size[col];
}

enum mod_bam_reporting_kpi_events_cols {
  mod_bam_reporting_kpi_events_first_output,
  mod_bam_reporting_kpi_events_first_perfdata,
};
constexpr static uint32_t mod_bam_reporting_kpi_events_size[] {
    65534,
    45,
};
constexpr uint32_t get_mod_bam_reporting_kpi_events_col_size(
    mod_bam_reporting_kpi_events_cols const& col) {
  return mod_bam_reporting_kpi_events_size[col];
}

enum mod_bam_reporting_timeperiods_cols {
  mod_bam_reporting_timeperiods_name,
  mod_bam_reporting_timeperiods_sunday,
  mod_bam_reporting_timeperiods_monday,
  mod_bam_reporting_timeperiods_tuesday,
  mod_bam_reporting_timeperiods_wednesday,
  mod_bam_reporting_timeperiods_thursday,
  mod_bam_reporting_timeperiods_friday,
  mod_bam_reporting_timeperiods_saturday,
};
constexpr static uint32_t mod_bam_reporting_timeperiods_size[] {
    200,
    200,
    200,
    200,
    200,
    200,
    200,
    200,
};
constexpr uint32_t get_mod_bam_reporting_timeperiods_col_size(
    mod_bam_reporting_timeperiods_cols const& col) {
  return mod_bam_reporting_timeperiods_size[col];
}

enum mod_bam_reporting_timeperiods_exceptions_cols {
  mod_bam_reporting_timeperiods_exceptions_daterange,
  mod_bam_reporting_timeperiods_exceptions_timerange,
};
constexpr static uint32_t mod_bam_reporting_timeperiods_exceptions_size[] {
    255,
    255,
};
constexpr uint32_t get_mod_bam_reporting_timeperiods_exceptions_col_size(
    mod_bam_reporting_timeperiods_exceptions_cols const& col) {
  return mod_bam_reporting_timeperiods_exceptions_size[col];
}

enum config_cols {
  config_RRDdatabase_path,
  config_RRDdatabase_status_path,
  config_RRDdatabase_nagios_stats_path,
  config_nagios_log_file,
};
constexpr static uint32_t config_size[] {
    255,
    255,
    255,
    255,
};
constexpr uint32_t get_config_col_size(
    config_cols const& col) {
  return config_size[col];
}

enum index_data_cols {
  index_data_host_name,
  index_data_service_description,
};
constexpr static uint32_t index_data_size[] {
    255,
    255,
};
constexpr uint32_t get_index_data_col_size(
    index_data_cols const& col) {
  return index_data_size[col];
}

enum log_action_cols {
  log_action_object_type,
  log_action_object_name,
  log_action_action_type,
};
constexpr static uint32_t log_action_size[] {
    255,
    255,
    255,
};
constexpr uint32_t get_log_action_col_size(
    log_action_cols const& col) {
  return log_action_size[col];
}

enum log_action_modification_cols {
  log_action_modification_field_name,
  log_action_modification_field_value,
};
constexpr static uint32_t log_action_modification_size[] {
    255,
    65534,
};
constexpr uint32_t get_log_action_modification_col_size(
    log_action_modification_cols const& col) {
  return log_action_modification_size[col];
}

enum log_archive_last_status_cols {
  log_archive_last_status_host_name,
  log_archive_last_status_service_description,
  log_archive_last_status_status,
};
constexpr static uint32_t log_archive_last_status_size[] {
    255,
    255,
    255,
};
constexpr uint32_t get_log_archive_last_status_col_size(
    log_archive_last_status_cols const& col) {
  return log_archive_last_status_size[col];
}

enum metrics_cols {
  metrics_metric_name,
  metrics_unit_name,
};
constexpr static uint32_t metrics_size[] {
    255,
    32,
};
constexpr uint32_t get_metrics_col_size(
    metrics_cols const& col) {
  return metrics_size[col];
}

enum nagios_stats_cols {
  nagios_stats_stat_key,
  nagios_stats_stat_value,
  nagios_stats_stat_label,
};
constexpr static uint32_t nagios_stats_size[] {
    255,
    255,
    255,
};
constexpr uint32_t get_nagios_stats_col_size(
    nagios_stats_cols const& col) {
  return nagios_stats_size[col];
}

enum log_traps_cols {
  log_traps_host_name,
  log_traps_ip_address,
  log_traps_agent_host_name,
  log_traps_agent_ip_address,
  log_traps_trap_oid,
  log_traps_trap_name,
  log_traps_vendor,
  log_traps_severity_name,
  log_traps_output_message,
};
constexpr static uint32_t log_traps_size[] {
    255,
    255,
    255,
    255,
    512,
    255,
    255,
    255,
    2048,
};
constexpr uint32_t get_log_traps_col_size(
    log_traps_cols const& col) {
  return log_traps_size[col];
}

enum log_traps_args_cols {
  log_traps_args_arg_oid,
  log_traps_args_arg_value,
};
constexpr static uint32_t log_traps_args_size[] {
    255,
    255,
};
constexpr uint32_t get_log_traps_args_col_size(
    log_traps_args_cols const& col) {
  return log_traps_args_size[col];
}



CCB_END()

#endif /* __TABLE_MAX_SIZE_HH__ */